﻿using System.CommandLine;
using MycroForge.Core;
using MycroForge.Core.Contract;

namespace MycroForge.CLI.Commands;

public partial class MycroForge
{
    public class Install : Command, ISubCommandOf<MycroForge>
    {
        private static readonly Argument<IEnumerable<string>> PackagesArgument =
            new(name: "packages", description: "The names of the packages to install");

        private readonly ProjectContext _context;

        public Install(ProjectContext context) :
            base("install", "Install packages and update the requirements.txt")
        {
            _context = context;
            AddAlias("i");
            AddArgument(PackagesArgument);
            this.SetHandler(ExecuteAsync, PackagesArgument);
        }

        private async Task ExecuteAsync(IEnumerable<string> packages)
        {
            await _context.Bash(
                "source .venv/bin/activate",
                $"pip install {string.Join(' ', packages)}",
                "pip freeze > requirements.txt"
            );
        }
    }
}